notetools
=========

.. automodule:: abjad.tools.notetools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.notetools.Harmonic.Harmonic.Harmonic
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic
      ~abjad.tools.notetools.Note.Note.Note
      ~abjad.tools.notetools.NoteHead.NoteHead.NoteHead

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.notetools.make_accelerating_notes_with_lilypond_multipliers.make_accelerating_notes_with_lilypond_multipliers
      ~abjad.tools.notetools.make_notes.make_notes
      ~abjad.tools.notetools.make_notes_with_multiplied_durations.make_notes_with_multiplied_durations
      ~abjad.tools.notetools.make_percussion_note.make_percussion_note
      ~abjad.tools.notetools.make_quarter_notes_with_lilypond_duration_multiplier.make_quarter_notes_with_lilypond_duration_multiplier
      ~abjad.tools.notetools.make_repeated_notes.make_repeated_notes
      ~abjad.tools.notetools.make_repeated_notes_from_time_signature.make_repeated_notes_from_time_signature
      ~abjad.tools.notetools.make_repeated_notes_from_time_signatures.make_repeated_notes_from_time_signatures
      ~abjad.tools.notetools.make_repeated_notes_with_shorter_notes_at_end.make_repeated_notes_with_shorter_notes_at_end
